@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-people" "1.8.1"
+(define-package "org-people" "20260302.1731"
   "Work with a contact-list in org-mode files."
-  '((emacs "29.1")
+  '((emacs "28.0")
     (org   "9.0"))
   :url "https://github.com/skx/org-people"
-  :commit "0423d6d0bfa7fb3540839954e9a05340f4898027"
-  :revdesc "0423d6d0bfa7"
+  :commit "85c83e8d896fe11718e4df050669b8d8064a5ac2"
+  :revdesc "85c83e8d896f"
   :keywords '("outlines" "contacts" "people"))
