@@ -4,9 +4,9 @@
 
 ;; Author: Steve Kemp
 ;; Maintainer: Steve Kemp
-;; Package-Version: 1.8.1
-;; Package-Revision: 0423d6d0bfa7
-;; Package-Requires: ((emacs "29.1") (org "9.0"))
+;; Package-Version: 20260302.1731
+;; Package-Revision: 85c83e8d896f
+;; Package-Requires: ((emacs "28.0") (org "9.0"))
 ;; Keywords: outlines, contacts, people
 ;; URL: https://github.com/skx/org-people
 
@@ -104,9 +104,6 @@
 
 ;;; Version history (brief)
 
-;;
-;; 1.8 - Improvement: Filtering on :TAGS property in `M-x org-people-summary`
-;;       uses sub-string matches of entries, rather than membership testing.
 ;;
 ;; 1.7 - BugFix: First column in org-people-summary-properties is used as the
 ;;       default sort key.  Now allows a width to be defined too.
@@ -586,7 +583,7 @@ using the org-people: handler."
     (when (re-search-forward org-property-drawer-re
                              (save-excursion (org-end-of-subtree t t))
                              t)
-      (org-fold-region (match-beginning 0)
+      (org-flag-region (match-beginning 0)
                        (match-end 0)
                        nil))))
 
@@ -767,17 +764,12 @@ We just make the name bold."
     ;; Filter list
     (let ((filtered
            (org-people-filter
-             (lambda (plist)
-               (let ((v (plist-get plist prop)))
-                 (cond
-                  ((listp v)
-                   (seq-some (lambda (item)
-                               (and (stringp item)
-                                    (string-match-p value item)))
-                             v))
-                  ((stringp v)
-                   (string-match-p value v))
-                  (t nil)))))))
+            (lambda (plist)
+              (let ((v (plist-get plist prop)))
+                (cond
+                 ((listp v) (member value v))
+                 ((stringp v) (string-match value v))
+                 (t nil)))))))
       ;; Refresh buffer
       (with-current-buffer org-people-summary-buffer-name
         (let ((inhibit-read-only t))
